package com.kernelmaft.zanbur

import androidx.compose.foundation.layout.Arrangement.Center
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.ColumnScope
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment.Companion.CenterHorizontally
import androidx.compose.ui.Modifier



@Composable fun AppFrame ( content : @Composable () -> Unit ) {
	ZanburTheme {
		Scaffold { scaffoldPadding ->
			CenteringColumn ( Modifier . padding (scaffoldPadding) . fillMaxSize () ) {
				content ()
			}
		}
	}
}

@Composable fun SceneSwitcher ( group : Group , onSwitch : (Scene) -> Unit ) {
	CenteringColumn {
		Text ( group . name )
		Spacer ( Modifier . height ( compactSpacing ) )

		for ( scene in group . scenes ) {
			val colors =
				if ( scene . id == group . currentScene ?. id ) ButtonDefaults . buttonColors ()
				else ButtonDefaults . filledTonalButtonColors ()

			Button (
				{ onSwitch (scene) } ,
				Modifier . fillMaxWidth () ,
				true ,
				ButtonDefaults . shape ,
				colors ,
			) {
				Text ( scene . name )
			}
		}
	}
}

@Composable fun CenteringColumn (
	modifier : Modifier = Modifier ,
	content : @Composable ColumnScope . () -> Unit ,
) = Column ( modifier , Center , CenterHorizontally , content )
